@@ -1374,10 +1374,10 @@ advanced_backlight_plugin_dsme_update_brightness_thread (gpointer d)
         {
           g_debug ("priv->brightness_level=%d\n", value);
 
-          //if (priv->is_770)
+          if (priv->is_770)
             advanced_backlight_plugin_770_update_brightness_value (priv, value);
-          //else
-          //  advanced_backlight_plugin_dsme_update_brightness_value (priv, value);
+          else
+            advanced_backlight_plugin_dsme_update_brightness_value (priv, value);
           prev_value = value;
         }
     }
